@@ -1,10 +1,12 @@
-/*-------------------------------------------------------------------------*/
-/* Copyright (c) 2002  Tim Edwards, Johns Hopkins University        	   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Copyright (c) 2002  Tim Edwards, Johns Hopkins University        	*/
+/*----------------------------------------------------------------------*/
 
-/*-------------------------------------------------------------------------*/
-/* Spun off from xcircuit.c 10/4/98 in the hopes of expanding it sometime. */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Spun off from xcircuit.c 10/4/98					*/
+/* Functionality will not be expanded in the Xt version.  All new	*/
+/* capabilities will be developed in the TCL version of help.		*/
+/*----------------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <string.h>
@@ -14,18 +16,20 @@
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
 
-#ifdef TCL_WRAPPER 
+#ifdef TCL_WRAPPER
 #include <tk.h>
 #else
+
 #include "Xw/Xw.h"
 #include "Xw/Form.h"
 #include "Xw/WorkSpace.h"
 #include "Xw/MenuBtn.h"
+
 #endif
 
-/*-------------------------------------------------------------------------*/
-/* Local includes							   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Local includes							*/
+/*----------------------------------------------------------------------*/
 
 #include "colordefs.h"
 #include "xcircuit.h"
@@ -36,14 +40,16 @@
 /*----------------------------------------------------------------------*/
 #include "prototypes.h"
 
-/*-------------------------------------------------------------------------*/
-/* Global Variable definitions						   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Global Variable definitions						*/
+/*----------------------------------------------------------------------*/
 
 #ifdef TCL_WRAPPER
 extern Tcl_Interp *xcinterp;
 #endif
 
+#ifndef TCL_WRAPPER
+
 extern Display    *dpy;
 extern GC	  hgc;
 extern Clientdata areastruct;
@@ -74,16 +80,11 @@ void printhelppix()
 {
    static char *helptitle = "Macro Key Binding Summary:";
    static helpstruct helptext[] = {
-    { XCF_Start,	"Start"},
     { XCF_Finish,	"Finish"},
     { XCF_Cancel,	"Cancel"},
     { XCF_Zoom_In,	"Zoom in 3/2"},
     { XCF_Zoom_Out,	"Zoom out 3/2"},
-    { XCF_Pan,		"Pan to center"},
-    { XCF_Pan_Up,	"Half-page pan Up"},
-    { XCF_Pan_Down,	"Half-page pan Down"},
-    { XCF_Pan_Right,	"Half-page pan Right"},
-    { XCF_Pan_Left,	"Half-page pan Left"},
+    { XCF_Pan,		"Pan (various modes)"},
     { XCF_Double_Snap,	"Double snap-to spacing"},
     { XCF_Halve_Snap,	"Halve snap-to spacing"},
     { XCF_Next_Library,	"Go To Next Library"},
@@ -292,24 +293,6 @@ void printhelppix()
     XDrawLine(dpy, helppix, hgc, 0, t1 + 7, helpwidth, t1 + 7);
 }
 
-#ifdef TCL_WRAPPER
-
-/*----------------------------------------------*/
-/* Map the help popup window	(Xt version)	*/
-/*----------------------------------------------*/
-
-void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
-{
-   Tk_Window popup, hspace;
-
-   Tcl_Eval(xcinterp, "wm deiconify .help");
-   hspace = Tk_NameToWindow(xcinterp, ".help.listwin.win", areastruct.area);
-   if (Tk_IsMapped(hspace))
-      exposehelp(hspace, NULL, NULL);
-}
-
-#else
-
 /*----------------------------------------------*/
 /* Create the help popup window	(Xt version)	*/
 /*----------------------------------------------*/
@@ -430,8 +413,6 @@ void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
    XtAddCallback(hsb, XtNexpose, (XtCallbackProc)showhsb, NULL);
 }
 
-#endif
-
 /*----------------------------------------------*/
 /* Very simple scroll mechanism	 (grab-and-pan)	*/
 /*----------------------------------------------*/
@@ -486,12 +467,8 @@ void exposehelp(xcWidget hspace, caddr_t clientdata, caddr_t calldata)
 {
    Arg wargs[1];
 
-#ifdef TCL_WRAPPER
-   hheight = Tk_Height(hspace);
-#else
    XtSetArg(wargs[0], XtNheight, &hheight);
    XtGetValues(hspace, wargs, 1);
-#endif
 
    if (helppix == (Pixmap)NULL) printhelppix();
    if (hheight < 1) hheight = 1;
@@ -518,4 +495,15 @@ void printhelp(xcWidget hspace)
    while (XCheckWindowEvent(dpy, hwin, ExposureMask, &discard) == True);
 }
 
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* The TCL version assumes the existence of command "helpwindow".	*/
+/*----------------------------------------------------------------------*/
+
+#else
+
+void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
+{
+   Tcl_Eval(xcinterp, "catch xcircuit::helpwindow");
+}
+
+#endif /* !TCL_WRAPPER */
