@@ -102,14 +102,14 @@ void catreturn()
 /*   page number of page to the right.  		*/
 /*------------------------------------------------------*/
 
-int pageposition(short libmode, XButtonEvent *event, int mode)
+int pageposition(short libmode, int x, int y, int mode)
 {
    int xin, yin, bpage, pages;
    int gxsize, gysize, xdel, ydel;
 
    pages = (libmode == PAGELIB) ? xobjs.pages : xobjs.numlibs;
    computespacing(libmode, &gxsize, &gysize, &xdel, &ydel);
-   window_to_user(event->x, event->y, &areastruct.save);
+   window_to_user(x, y, &areastruct.save);
 
    if (mode == 0) {	/* On-page */
       if (areastruct.save.x >= 0 && areastruct.save.y <= 0) {
@@ -297,7 +297,7 @@ int check_library(char *libname)
 /* ButtonPress handler during page catalog viewing mode */
 /*------------------------------------------------------*/
 
-void pagecatbutton(XButtonEvent *event)
+void pagecat_op(int op, int x, int y)
 {
    int bpage;
    short mode;
@@ -307,8 +307,8 @@ void pagecatbutton(XButtonEvent *event)
    }
    if (mode == LIBRARY) return;  /* Something went wrong if this happens */
 
-   if (event->button == Button1 || event->button == Button2) {
-      if ((bpage = pageposition(mode, event, 0)) >= 0) {
+   if (op != XCF_Cancel) {
+      if ((bpage = pageposition(mode, x, y, 0)) >= 0) {
 		  
 	 if (eventmode == ASSOC_MODE) {
 	    if (mode == PAGELIB) {
@@ -318,31 +318,31 @@ void pagecatbutton(XButtonEvent *event)
 	       schemassoc(topobject, areastruct.stack->thisinst->thisobject);
 	       /* pop back to calling (symbol) page */
 	       catreturn();
-	       eventmode = PRESS_MODE;
+	       eventmode = MOVE_MODE;
 	    }
 	    else {
 	       startcatalog(NULL, (pointertype)(LIBRARY + bpage), NULL);
 	    }
 	    return;
          }
-	 else if (event->button == Button1) {
+	 else if (op == XCF_Select) {
+	    if (mode == PAGELIB)    /* No such method for LIBLIB is defined. */
+	       select_add_element(OBJINST);
+	 }
+	 else if ((op == XCF_Library_Pop) || (op == XCF_Finish)) {
 
 	    /* like catreturn(), but don't actually go to the popped page */
 	    unselect_all();
 	    eventmode = NORMAL_MODE;
 	    if (mode == PAGELIB) {
 	       newpage(bpage);
-      	       eventmode = PRESS_MODE;
+      	       eventmode = MOVE_MODE;
 	    }
 	    else {
 	       startcatalog(NULL, (pointertype)(LIBRARY + bpage), NULL);
 	    }
 	    return;
 	 }
-	 else {  /* Button2 */
-	    if (mode == PAGELIB)    /* No such method for LIBLIB is defined. */
-	       select_add_element(OBJINST);
-	 }
       }
    }
    else {
@@ -566,7 +566,7 @@ void updatepagelib(short mode, short tpage)
 /* Rearrange pages	*/
 /*----------------------*/
 
-void pagecatmove(XKeyEvent *event)
+void pagecatmove(int x, int y)
 {
    int bpage;
    objinstptr exchobj;
@@ -600,7 +600,7 @@ void pagecatmove(XKeyEvent *event)
 
    /* If one object selected; find place to put from cursor position */
 
-   else if ((bpage = pageposition(PAGELIB, (XButtonEvent *)event, 1)) >= 0) {
+   else if ((bpage = pageposition(PAGELIB, x, y, 1)) >= 0) {
       int k, epage;
       Pagedata *eptr;
 
@@ -1081,7 +1081,7 @@ void linkedlistinsertafter(liblistptr *spec, int o1, int o2)
 /* Rearrange objects in the library			*/
 /*------------------------------------------------------*/
 
-void catmove(XKeyEvent *event)
+void catmove(int x, int y)
 {
    int i, j, s1, s2, ocentx, ocenty, rangex, rangey;
    liblistptr spec;
@@ -1090,7 +1090,7 @@ void catmove(XKeyEvent *event)
    /* make catmove() a wrapper for pagecatmove() */
 
    if ((i = is_library(topobject)) < 0) {
-      pagecatmove(event);
+      pagecatmove(x, y);
       return;
    }
 
@@ -1128,7 +1128,7 @@ void catmove(XKeyEvent *event)
    }
    else {	/* one object selected; find place to put from cursor position */
 
-      window_to_user(event->x, event->y, &areastruct.save);
+      window_to_user(x, y, &areastruct.save);
 
       s2 = -1;
       for (j = 0, spec = xobjs.userlibs[i].instlist; spec != NULL;
@@ -1356,7 +1356,7 @@ void copycat()
 /* ButtonPress handler during normal catalog viewing mode */
 /*--------------------------------------------------------*/
 
-void catbutton(u_int mode, XButtonEvent *event)
+void catalog_op(int op, int x, int y)
 {
    short *newselect;
    objinstptr *newobject, *libobj;
@@ -1364,16 +1364,22 @@ void catbutton(u_int mode, XButtonEvent *event)
    short ocentx, ocenty, rangex, rangey, xdiff, ydiff, flag = 0;
    XPoint oldpos;
 
-   /* Make catbutton() a wrapper for pagecatbutton() */
+   /* Make catalog_op() a wrapper for pagecat_op() */
 
    if (is_library(topobject) < 0) {
-      pagecatbutton(event);
+      pagecat_op(op, x, y);
       return;
    }
 
-   if (event->button == Button1 || event->button == Button2) {
+   /* If XCF_Cancel was invoked, return without a selection. */
 
-      window_to_user(event->x, event->y, &areastruct.save);
+   if (op == XCF_Cancel) {
+      eventmode = NORMAL_MODE;
+      catreturn();
+   }
+   else {
+
+      window_to_user(x, y, &areastruct.save);
 	
       for (libobj = (objinstptr *)topobject->plist; libobj <
 		(objinstptr *)topobject->plist + topobject->parts; libobj++) {
@@ -1405,9 +1411,9 @@ void catbutton(u_int mode, XButtonEvent *event)
 		  schemassoc(topobject, (*libobj)->thisobject); 
    	          setpage(TRUE);
 		  catreturn();
-		  eventmode = PRESS_MODE;
+		  eventmode = MOVE_MODE;
 	       }
-	       else if (event->button == Button1) {
+	       else if ((op == XCF_Library_Pop) || (op == XCF_Library_Copy)) {
 
 	          /* revert to old page */
 
@@ -1418,11 +1424,11 @@ void catbutton(u_int mode, XButtonEvent *event)
 	          /* retrieve drawing window state and set position of object to
 	             be correct in reference to that window */
 
-	          snap(event->x, event->y, &oldpos);
+	          snap(x, y, &oldpos);
 
    	          setpage(FALSE);
 	    
-	          snap(event->x, event->y, &areastruct.save);
+	          snap(x, y, &areastruct.save);
 	          xdiff = areastruct.save.x - oldpos.x;
 	          ydiff = areastruct.save.y - oldpos.y;
 
@@ -1461,19 +1467,19 @@ void catbutton(u_int mode, XButtonEvent *event)
                      *newselect = (short)(newobject - (objinstptr *)topobject->plist);
 
 	          }
-	          if ((void *)mode == (void *)(1)) {
+	          if (op == XCF_Library_Copy) {
 
-		     /* key "c" pressed for "copy" */
+		     /* Key "c" pressed for "copy" (default binding) */
 
                      XDefineCursor(dpy, areastruct.areawin, COPYCURSOR);
-                     eventmode = COPY2_MODE;
+                     eventmode = COPY_MODE;
 #ifndef TCL_WRAPPER
                      xcAddEventHandler(areastruct.area, PointerMotionMask, False,
-			  (xcEventHandler)drag, NULL);
+			  (xcEventHandler)xlib_drag, NULL);
 #endif
 	          }
 	          else {
-                     eventmode = PRESS_MODE;
+                     eventmode = MOVE_MODE;
 	          }
 #ifdef TCL_WRAPPER
 		  /* fprintf(stderr, "Creating event handler for xctk_drag: "); */
@@ -1486,11 +1492,11 @@ void catbutton(u_int mode, XButtonEvent *event)
                   catreturn();
                }
 
-               /* If button2 was pressed, select and stay in the catalog.  */
+               /* Select the closest element and stay in the catalog.	   */
 	       /* Could just do "select_element" here, but would not cover */
 	       /* the entire area in the directory surrounding the object. */
 
-	       else {
+	       else if (op == XCF_Select) {
 		  short newinst = (short)(libobj - (objinstptr *)topobject->plist);
 		  /* (ignore this object if it is already in the list of selects) */
 		  for (newselect = areastruct.selectlist; newselect <
@@ -1509,12 +1515,6 @@ void catbutton(u_int mode, XButtonEvent *event)
 	 }
       }
    }
-   /* If button3 was pressed, return without a selection. */
-
-   else {
-      eventmode = NORMAL_MODE;
-      catreturn();
-   }
 }
 
 /*------------------------------*/
@@ -1553,17 +1553,17 @@ void startcatalog(xcWidget w, pointertype libmod, caddr_t nulldata)
 		(areastruct.topinstance == xobjs.libtop[libmod])) return;
 
    if (libmod == FONTLIB) {
-      XDefineCursor (dpy, areastruct.areawin, CROSS);
-      if (eventmode == TEXT2_MODE)
+      XDefineCursor (dpy, areastruct.areawin, DEFAULTCURSOR);
+      if (eventmode == TEXT_MODE)
          eventmode = FONTCAT_MODE;
       else
-         eventmode = FONTCAT2_MODE;
+         eventmode = EFONTCAT_MODE;
    }
    else if (eventmode == ASSOC_MODE) {
-      XDefineCursor (dpy, areastruct.areawin, CROSS);
+      XDefineCursor (dpy, areastruct.areawin, DEFAULTCURSOR);
    }
    else if (libmod == PAGELIB || libmod == LIBLIB) {
-      XDefineCursor (dpy, areastruct.areawin, CROSS);
+      XDefineCursor (dpy, areastruct.areawin, DEFAULTCURSOR);
       eventmode = CATALOG_MODE;
    }
    else
