@@ -78,11 +78,9 @@ extern void drawdot(int, int);
 extern void copyalleparams(genericptr, genericptr);
 extern void copyparams(objinstptr, objinstptr);
 
-extern void startspline(xcWidget, caddr_t, caddr_t);
-extern void starttext(xcWidget, pointertype, caddr_t);
-extern void textbutton(u_char, XButtonEvent *);
+extern void textbutton(u_char, int, int);
 extern void charreport(labelptr);
-extern void labeltext(int, char *);
+extern Boolean labeltext(int, char *);
 extern void textreturn();
 extern void rejustify(short);
 extern void finddir(polyptr);
@@ -96,19 +94,17 @@ extern Boolean neartest(XPoint *, XPoint *);
 extern void join();
 
 /* interactive manipulation of elements */
-extern void splinebutton(XButtonEvent *);
+extern void splinebutton(int, int);
 extern void trackspline(xcWidget, caddr_t, caddr_t);
-extern void startarc(xcWidget, caddr_t, caddr_t);
-extern void arcbutton(XButtonEvent *);
+extern void arcbutton(int, int);
 extern void trackarc(xcWidget, caddr_t, caddr_t);
-extern void startbox(xcWidget, caddr_t, caddr_t);
-extern void boxbutton(XButtonEvent *);
+extern void boxbutton(int, int);
 extern void trackbox(xcWidget, caddr_t, caddr_t);
 extern void trackwire(xcWidget, caddr_t, caddr_t);
 extern void startwire(XPoint);
 extern void trackpoly(xcWidget, caddr_t, caddr_t);
 extern void setendpoint(short *, short, XPoint **, XPoint *);
-extern void wirebutton(XButtonEvent *);
+extern void wire_op(int, int ,int);
 
 /* from events.c: */
 
@@ -118,7 +114,6 @@ extern void newmatrix();
 extern void setpage(Boolean);
 extern int changepage(short);
 extern void newpage(short);
-extern void startpush(xcWidget, caddr_t, caddr_t);
 extern void pushobject(objinstptr);
 extern void push_stack(pushlistptr *, objinstptr);
 extern void pop_stack(pushlistptr *);
@@ -132,14 +127,13 @@ extern void endhbar(xcWidget, caddr_t, XButtonEvent *);
 extern void panvbar(xcWidget, caddr_t, XButtonEvent *);
 extern void endvbar(xcWidget, caddr_t, XButtonEvent *);
 extern void zoombox(xcWidget, caddr_t, caddr_t);
-extern void zoomin(xcWidget, caddr_t, XButtonEvent *);
-extern void zoomout(xcWidget, caddr_t, XButtonEvent *);
+extern void zoomin(int, int);
+extern void zoomout(int, int);
 extern void warppointer(int, int);
-extern void panbutton(u_int, XButtonEvent *);
-extern void zoominrefresh(xcWidget, caddr_t, XButtonEvent *);
-extern void zoomoutrefresh(xcWidget, caddr_t, XButtonEvent *);
-extern void panrefresh(u_int, XButtonEvent *);
-extern void centerpan(xcWidget, caddr_t, caddr_t);
+extern void panbutton(u_int, int, int);
+extern void zoominrefresh(int, int);
+extern void zoomoutrefresh(int, int);
+extern void panrefresh(u_int, int, int);
 extern void checkwarp(XPoint *);
 extern int checkcycle(short, short);
 extern void copyvirtual();
@@ -148,6 +142,9 @@ extern void nextsplinecycle(splineptr, short);
 extern void nextarccycle(arcptr, short);
 extern void buttonhandler(xcWidget, caddr_t, XButtonEvent *);
 extern void keyhandler(xcWidget, caddr_t, XKeyEvent *);
+extern Boolean compatible_function(int);
+extern void eventdispatch(int, int, int);
+extern void releasehandler(xcWidget, caddr_t, XKeyEvent *);
 extern void setsnap(short);
 extern void snapelement();
 extern int ipow10(int);
@@ -158,11 +155,11 @@ extern void findwirex(XPoint *, XPoint *, XPoint *, XPoint *, int *);
 extern void findattach(XPoint *, int *, XPoint *);
 extern XPoint *pathclosepoint(pathptr, XPoint *);
 extern void placeselects(short, short, XPoint *);
-extern void drag(xcWidget, caddr_t, XButtonEvent *);
-extern void rotatebutton(XButtonEvent *);
+extern void drag(int, int);
+extern void xlib_drag(xcWidget, caddr_t, XEvent *);
 extern void elemrotate(genericptr *, short);
 extern void elementrotate(short);
-extern void edit(XButtonEvent *);
+extern void edit(int, int);
 extern void pathedit(genericptr *, short);
 extern void xc_lower(short *);
 extern void xc_raise(short *);
@@ -176,12 +173,8 @@ extern xcTimeOutProc makepress(caddr_t);
 #else
 extern xcTimeOutProc makepress(caddr_t, xcIntervalId *);
 #endif
-extern void startrotate(xcWidget, pointertype, caddr_t);
-extern void startcopy(xcWidget, caddr_t, caddr_t);
-extern void startedit(xcWidget, caddr_t, caddr_t);
-extern void startdelete(xcWidget, caddr_t, caddr_t);
 extern void reviseselect(short *, int, short *);
-extern void deletebutton(XButtonEvent *);
+extern void deletebutton(int, int);
 extern short *xc_undelete(objinstptr, objectptr, short, short *);
 extern objectptr delete_element(objinstptr, short *, int, short);
 extern void printname(objectptr);
@@ -200,10 +193,11 @@ extern void arccopy(arcptr, arcptr);
 extern void polycopy(polyptr, polyptr);
 extern void splinecopy(splineptr, splineptr);
 extern void instcopy(objinstptr, objinstptr);
-extern void copybutton(XButtonEvent *);
-extern void selectbutton(XButtonEvent *);
-extern void releasebutton(XButtonEvent *);
-extern void pathbutton(genericptr *, XButtonEvent *);
+extern void copy_op(int, int, int);
+extern Boolean checkmultiple(XButtonEvent *);
+extern void continue_op(int, int, int);
+extern void finish_op(int, int, int);
+extern void path_op(genericptr *, int, int, int);
 extern void resizearea(xcWidget, caddr_t, caddr_t);
 extern void drawarea(xcWidget, caddr_t, caddr_t);
 extern void standard_element_delete(short);
@@ -408,6 +402,7 @@ extern int firstbinding(int);
 extern Boolean ismacro(int);
 extern Boolean isbound(int, int);
 extern Boolean isnbound(int, int, short *);
+extern int boundfunction(int, int);
 extern int string_to_func(const char *, short *);
 extern int string_to_key(const char *);
 extern char *binding_to_string(int, int);
@@ -421,30 +416,35 @@ extern void default_keybindings();
 extern int remove_binding(int, int);
 extern void remove_keybinding(const char *, const char *);
 
+#ifndef TCL_WRAPPER
+extern void mode_rebinding(int, int);
+extern void mode_tempbinding(int, int);
+#endif
+
 /* from libraries.c: */
 
 extern short findhelvetica();
 extern void catreturn();
-extern int pageposition(short, XButtonEvent *, int);
+extern int pageposition(short, int, int, int);
 extern short pagelinks();
 extern short *pagetotals(int, short);
 extern int is_page(objectptr);
 extern int is_library(objectptr);
-extern void pagecatbutton(XButtonEvent *);
+extern void pagecat_op(int, int, int);
 extern void pageinstpos(short, short, objinstptr, int, int, int, int);
 extern objinstptr newpageinst(objectptr);
 extern void computespacing(short, int *, int *, int *, int *);
 extern void composepagelib(short);
 extern void updatepagelib(short, short);
-extern void pagecatmove(XKeyEvent *);
+extern void pagecatmove(int, int);
 extern void composelib(short);
 extern short finddepend(objinstptr, objectptr **);
 extern void cathide();
 extern void catvirtualcopy();
 extern void catdelete();
-extern void catmove(XKeyEvent *);
+extern void catmove(int, int);
 extern void copycat();
-extern void catbutton(u_int, XButtonEvent *);
+extern void catalog_op(int, int, int);
 extern void changecat();
 extern void startcatalog(xcWidget, pointertype, caddr_t);
 
@@ -487,6 +487,8 @@ extern void makenewencodingbutton(char *, char);
 extern void togglefontmark(int);
 #ifndef TCL_WRAPPER
 extern void toggleexcl(xcWidget, menuptr, int);
+extern void highlightexcl(xcWidget, int, int);
+extern void toolcursor(int);
 extern void promptparam(xcWidget, caddr_t, caddr_t);
 #endif
 extern void stringparam(xcWidget, caddr_t, caddr_t);
@@ -513,6 +515,10 @@ extern void setfill(xcWidget, pointertype, caddr_t);
 extern void makebbox(xcWidget, pointertype, caddr_t);
 extern void setclosure(xcWidget, pointertype, caddr_t);
 extern void setopaque(xcWidget, pointertype, caddr_t);
+extern void changetool(xcWidget, pointertype, caddr_t);
+extern void exec_or_changetool(xcWidget, pointertype, caddr_t);
+extern void rotatetool(xcWidget, pointertype, caddr_t);
+extern void pantool(xcWidget, pointertype, caddr_t);
 #endif
 extern int setline(xcWidget, pointertype, caddr_t);
 #ifdef TCL_WRAPPER
@@ -604,7 +610,7 @@ extern char *parseinfo(objectptr, CalllistPtr, char *, char *, Boolean);
 extern int writedevice(FILE *, char *, objectptr, CalllistPtr, char *);
 extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
 extern void writeglobals(objectptr, FILE *);
-extern void writehierarchy(objectptr, CalllistPtr, FILE *);
+extern void writehierarchy(objectptr, CalllistPtr, FILE *, char *);
 extern void writenet(objectptr, char *, char *);
 extern Boolean writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
 extern void outputpcb(struct Ptab *, FILE *);
@@ -695,6 +701,15 @@ extern void invalidate_graphics(objectptr);
 extern void freegraphic(graphicptr);
 extern short *collect_graphics(short *);
 
+/* from flate.c */
+
+#ifdef HAVE_LIBZ
+extern unsigned long ps_deflate (unsigned char *, unsigned long,
+	unsigned char *, unsigned long);
+extern unsigned long ps_inflate (unsigned char *, unsigned long,
+	unsigned char **, unsigned long);
+#endif
+
 /* from render.c: */
 
 extern void ghostinit();
@@ -765,11 +780,7 @@ extern void clearselects();
 extern void unselect_all();
 extern selection *recurselect(short, u_char, pushlistptr *);
 extern short *recurse_select_element(short, u_char);
-#ifdef TCL_WRAPPER
-extern xcTimeOutProc startselect(caddr_t);
-#else
-extern xcTimeOutProc startselect(caddr_t, xcIntervalId *);
-#endif
+extern void startselect();
 extern void trackselarea();
 
 /* from text.c: */
@@ -811,7 +822,7 @@ extern TextExtents ULength(stringpart *, objinstptr, float, short, XPoint *);
 extern void undrawtext(labelptr);
 extern void redrawtext(labelptr);
 extern void composefontlib(short);
-extern void fontcatbutton(XButtonEvent *);
+extern void fontcat_op(int, int, int);
 
 /* from xcircuit.c: */
 
