@@ -361,8 +361,8 @@ selection *genselectelement(short class, u_char mode, objectptr selobj,
       /* when selection element to attach to, don't select the element */
       /* to be attached. . .					       */
 
-      if (attachto == 1 && eventmode != COPY2_MODE && eventmode !=
-	    PRESS_MODE && curgen == EDITPART) continue;
+      if (attachto == 1 && eventmode != COPY_MODE && eventmode !=
+	    MOVE_MODE && curgen == EDITPART) continue;
 
       selected = False;
 
@@ -697,10 +697,6 @@ void startdesel(xcWidget w, caddr_t clientdata, caddr_t calldata)
 	 Wprintf("Nothing to deselect!");
       else if (areastruct.selects == 1)
 	 unselect_all();
-      else {
-         eventmode = DESEL_MODE;
-         Wprintf("Click on element to deselect");
-      }
    }
 }
 
@@ -919,34 +915,23 @@ selection *recurselect(short class, u_char mode, pushlistptr *seltop)
 /* Start drawing a select area box. */
 /*----------------------------------*/
 
-#ifdef TCL_WRAPPER
-
-xcTimeOutProc startselect(caddr_t clientdata)
+void startselect()
 {
-   if (eventmode != PENDING_MODE) return;
    eventmode = SELAREA_MODE;
    areastruct.origin.x = areastruct.save.x;
    areastruct.origin.y = areastruct.save.y;
    UDrawBox(areastruct.origin, areastruct.save);
 
+#ifdef TCL_WRAPPER
    Tk_CreateEventHandler(areastruct.area, ButtonMotionMask,
 		(Tk_EventProc *)xctk_drag, NULL);
-}
-
 #else
-
-xcTimeOutProc startselect(caddr_t clientdata, xcIntervalId *id)
-
-{
-   if (eventmode != PENDING_MODE) return;
-   eventmode = SELAREA_MODE;
-   areastruct.origin.x = areastruct.save.x;
-   areastruct.origin.y = areastruct.save.y;
-   UDrawBox(areastruct.origin, areastruct.save);
-}
-
+   xcAddEventHandler(areastruct.area, ButtonMotionMask, False,
+		(xcEventHandler)xlib_drag, NULL);
 #endif
 
+}
+
 /*-------------------------*/
 /* Track a select area box */
 /*-------------------------*/
@@ -978,9 +963,8 @@ void trackrescale()
    newpos = UGetCursorPos();
    if (newpos.x == areastruct.save.x && newpos.y == areastruct.save.y) return;
 
-   /* To be done---handle vs. editpart */
-   UDrawRescaleBox(areastruct.save);
-   UDrawRescaleBox(newpos);
+   UDrawRescaleBox(&areastruct.save);
+   UDrawRescaleBox(&newpos);
 
    areastruct.save.x = newpos.x;
    areastruct.save.y = newpos.y;
