@@ -27,6 +27,7 @@ extern int xctcl_standardaction();
 extern int xctcl_refresh();
 extern int xctcl_library();
 extern int xctcl_font();
+extern int xctcl_cursor();
 extern int xctcl_bind();
 extern int xctcl_filerecover();
 extern int xctcl_color();
@@ -83,6 +84,7 @@ static cmdstruct xc_commands[] =
    {"refresh", (void *)xctcl_refresh},
    {"library", (void *)xctcl_library},
    {"loadfont", (void *)xctcl_font},
+   {"cursor", (void *)xctcl_cursor},
    {"bindkey", (void *)xctcl_bind},
    {"filerecover", (void *)xctcl_filerecover},
    {"color", (void *)xctcl_color},
@@ -201,7 +203,10 @@ Xcircuit_Init(Tcl_Interp *interp)
    if (cadhome == NULL) cadhome = CAD_DIR;
    Tcl_SetVar(interp, "CAD_HOME", cadhome, TCL_GLOBAL_ONLY);
 
-   /* Set $XCIRCUIT_VERSION as a Tcl variable */
+   /* Set $XCIRCUIT_VERSION and $XCIRCUIT_REVISION as Tcl variables */
+
+   sprintf(version_string, "%d", PROG_REVISION);
+   Tcl_SetVar(interp, "XCIRCUIT_REVISION", version_string, TCL_GLOBAL_ONLY);
 
    sprintf(version_string, "%g", PROG_VERSION);
    Tcl_SetVar(interp, "XCIRCUIT_VERSION", version_string, TCL_GLOBAL_ONLY);
